pub struct ElectionGroupBallot {
pub election_group_identification: String,
pub domain_of_influence: String,
pub election_group_position: usize,
pub election_informations: Vec<ElectionInformation>,
}Fields
election_group_identification: Stringdomain_of_influence: Stringelection_group_position: usizeelection_informations: Vec<ElectionInformation>Implementations
Sourceimpl ElectionGroupBallot
impl ElectionGroupBallot
Validate if the election group has the given Authorization based on the domain of influence
Sourcepub fn number_of_elections(&self) -> usize
pub fn number_of_elections(&self) -> usize
Calculate the number of election in the election group
Sourcepub fn write_in_position_ids(&self) -> Vec<&str>
pub fn write_in_position_ids(&self) -> Vec<&str>
Collect of the ids of the write-in positions in the election group