pub struct ElectionInformation {
pub election: Election,
pub candidates: Vec<Candidate>,
pub lists: Vec<List>,
pub write_in_positions: Vec<WriteInPosition>,
pub empty_list: EmptyList,
}Fields
election: Electioncandidates: Vec<Candidate>lists: Vec<List>write_in_positions: Vec<WriteInPosition>empty_list: EmptyListImplementations
Sourceimpl ElectionInformation
impl ElectionInformation
Sourcepub fn write_in_position_ids(&self) -> Vec<&str>
pub fn write_in_position_ids(&self) -> Vec<&str>
Collect of the ids of the write-in positions in the election group
Sourcepub fn is_list(&self, id: &str) -> bool
pub fn is_list(&self, id: &str) -> bool
Test if the given id corresponds to a list, incl empty list
Sourcepub fn type_of_id<'a>(
&'a self,
id: &str,
accumulation_pos: Option<usize>,
) -> Option<TypeOfIdInElection<'a>>
pub fn type_of_id<'a>( &'a self, id: &str, accumulation_pos: Option<usize>, ) -> Option<TypeOfIdInElection<'a>>
Calculate TypeOfIdInElection of the id
accumulation_pos corresponds to the position of the candidate in a pre-accumulated list
Return None if the id was not found in ElectionInformation