Module verification

Module verification 

Module implementing all the verifications

Structs

ManualVerificationsSetup
Data for the manual verifications on the setup
ManualVerificationsTally
Data for the manual verifications on the tally
VerficationsWithErrorAndFailures
Type representing verifications with errors and failures
VerificationError
Error during the verification process
VerificationErrorsFailureInformation
VerificationEvent
Enum representing one event (an error or a failure) during the tests
VerificationMetaData
Metadata of a verification
VerificationMetaDataList
List of Verification Metadata
VerificationResult
Struct representing a result of the verification The verification can have many errors and/or many failures
VerificationSuite
Enum for the suite of verifications
VerificationsResult
Data for the results of the verifications

Enums

ManualVerifications
Enum for the manual verifications (for setup oder tally)
VerificationCategory
VerificationPeriod
VerificationStatus
Status of a verification

Traits

ManualVerificationInformationTrait
Trait to get the information of the manual verifications in form of string

Functions

get_verifications_setup
Collect the verifications of the submodules
get_verifications_tally