pub struct VerificationResult { /* private fields */ }Expand description
Struct representing a result of the verification The verification can have many errors and/or many failures
Implementations
Sourceimpl VerificationResult
impl VerificationResult
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Has the result errors
Sourcepub fn has_failures(&self) -> bool
pub fn has_failures(&self) -> bool
Has the result failures
Sourcepub fn errors(&self) -> Vec<&VerificationEvent>
pub fn errors(&self) -> Vec<&VerificationEvent>
Get the errors
Sourcepub fn failures(&self) -> Vec<&VerificationEvent>
pub fn failures(&self) -> Vec<&VerificationEvent>
Get the failures
Sourcepub fn errors_to_string(&self) -> Vec<String>
pub fn errors_to_string(&self) -> Vec<String>
Get the errors as string
Sourcepub fn failures_to_string(&self) -> Vec<String>
pub fn failures_to_string(&self) -> Vec<String>
Get the failures as string
Sourcepub fn errors_and_failures(&self) -> Vec<&VerificationEvent>
pub fn errors_and_failures(&self) -> Vec<&VerificationEvent>
Get the errors and the failures (all events)
Sourcepub fn add_context<C>(&mut self, context: C)
pub fn add_context<C>(&mut self, context: C)
Add the context to the contexts of self
Sourcepub fn clone_add_context<C>(self, context: C) -> Self
pub fn clone_add_context<C>(self, context: C) -> Self
Clone self and add the context
Sourcepub fn push(&mut self, e: VerificationEvent)
pub fn push(&mut self, e: VerificationEvent)
Push a new error or failure to the VerificationResult
Sourcepub fn push_with_context<C>(&mut self, e: VerificationEvent, context: C)
pub fn push_with_context<C>(&mut self, e: VerificationEvent, context: C)
Push a new error or failure to the VerificationResult add the given context
Sourcepub fn append(&mut self, other: &mut Self)
pub fn append(&mut self, other: &mut Self)
Append the results of ohter to self, emptying the vectors of other
Sourcepub fn append_with_context<C>(&mut self, other: &Self, context: C)
pub fn append_with_context<C>(&mut self, other: &Self, context: C)
Append the results of ohter to self with context
Sourcepub fn append_vec(&mut self, other: &mut Vec<VerificationEvent>)
pub fn append_vec(&mut self, other: &mut Vec<VerificationEvent>)
Append the results of ohter to self, emptying the vectors of other
Sourcepub fn append_errors_from_string_slice(&mut self, errors: &[String])
pub fn append_errors_from_string_slice(&mut self, errors: &[String])
Append strings to self as errors
Sourcepub fn append_failures_from_string_slice(&mut self, failures: &[String])
pub fn append_failures_from_string_slice(&mut self, failures: &[String])
Append strings to self as failures
Sourcepub fn new_errors_from_string_slice(errors: &[String]) -> Self
pub fn new_errors_from_string_slice(errors: &[String]) -> Self
Create new Self with errors from strings
Sourcepub fn new_failures_from_string_slice(errors: &[String]) -> Self
pub fn new_failures_from_string_slice(errors: &[String]) -> Self
Create new Self with failures from strings
Sourcepub fn join_with_context<C>(data: &[Self], context: C) -> Self
pub fn join_with_context<C>(data: &[Self], context: C) -> Self
Join a &Self with context